@@ -44,9 +44,9 @@
 
 void phoc_trace_mark (gint64       begin_time_nsec,
                       gint64       duration_nsec,
-                      const gchar *group,
-                      const gchar *name,
-                      const gchar *message_format,
+                      const char  *group,
+                      const char  *name,
+                      const char  *message_format,
                       ...) G_GNUC_PRINTF (5, 6);
 #else
 # define PHOC_TRACE_CURRENT_TIME 0
