@@ -144,7 +144,7 @@ phoc_utils_scale_box (struct wlr_box *box, float scale)
  * @box: The box to check
  * @damage: The damaged area
  * @clip_box:(nullable): Box to clip damage to
- * @overlap_damage: (out): The overlap of the rectangle with the damaged area.
+ * @out_damage: (out): The overlap of the rectangle with the damaged area.
  *   Don't init the pixman region `is_damaged` does that for you.
  *
  * Checks if a given rectangle in `box` overlaps with a given damage area. If so
@@ -153,6 +153,9 @@ phoc_utils_scale_box (struct wlr_box *box, float scale)
  * If the optional `clip_box` is specified the damage is clipped to
  * that box.
  *
+ * Coordinates of the given boxes and regions need to be in output
+ * buffer local coordinates.
+ *
  * Returns: %TRUE on overlap otherwise %FALSE
  */
 gboolean
@@ -205,3 +208,37 @@ phoc_utils_wlr_surface_leave_output (struct wlr_surface *wlr_surface, struct wlr
 
   phoc_utils_wlr_surface_update_scales (wlr_surface);
 }
+
+
+const char *
+phoc_utils_transform_to_str (enum wl_output_transform transform)
+{
+  switch (transform) {
+  case WL_OUTPUT_TRANSFORM_NORMAL:
+    return "normal";
+    break;
+  case WL_OUTPUT_TRANSFORM_90:
+    return "90";
+    break;
+  case WL_OUTPUT_TRANSFORM_180:
+    return "180";
+    break;
+  case WL_OUTPUT_TRANSFORM_270:
+    return "270";
+    break;
+  case WL_OUTPUT_TRANSFORM_FLIPPED:
+    return "flipped";
+    break;
+  case WL_OUTPUT_TRANSFORM_FLIPPED_90:
+    return "flipped-90";
+    break;
+  case WL_OUTPUT_TRANSFORM_FLIPPED_180:
+    return "flipped-180";
+    break;
+  case WL_OUTPUT_TRANSFORM_FLIPPED_270:
+    return "flipped-270";
+    break;
+  default:
+    g_assert_not_reached ();
+  }
+}
