@@ -41,7 +41,7 @@ test_phoc_client_surface (void)
 }
 
 gint
-main (gint argc, gchar *argv[])
+main (gint argc, char *argv[])
 {
   g_test_init (&argc, &argv, NULL);
 
