@@ -416,7 +416,7 @@ test_layer_shell_popup (void)
 
 
 gint
-main (gint argc, gchar *argv[])
+main (gint argc, char *argv[])
 {
   g_test_init (&argc, &argv, NULL);
 
