@@ -47,7 +47,7 @@ test_phoc_server_setup_args (void)
 }
 
 gint
-main (gint argc, gchar *argv[])
+main (gint argc, char *argv[])
 {
   g_test_init (&argc, &argv, NULL);
 
