@@ -26,9 +26,12 @@ test_phoc_config_defaults (void)
 static void
 test_phoc_config_output (void)
 {
+  PhocOutputConfig *oc;
+
   g_autoptr (PhocConfig) config1 = phoc_config_new_from_data (
     "[output:X11-1]\n"
-    "scale = 3\n");
+    "scale = 3\n"
+    "adaptive-sync = enabled\n");
 
   g_autoptr (PhocConfig) config2 = phoc_config_new_from_data (
     "[output:X11-1]\n"
@@ -36,8 +39,12 @@ test_phoc_config_output (void)
     "[output:X11-2]\n"
     "scale = 3\n");
 
+  oc = config1->outputs->data;
   g_assert_cmpint (g_slist_length (config1->outputs), ==, 1);
-  g_assert_cmpint (((PhocOutputConfig*)config1->outputs->data)->scale, ==, 3);
+  g_assert_cmpfloat (oc->scale, ==, 3.0);
+  g_assert_cmpint (oc->adaptive_sync, ==, PHOC_OUTPUT_ADAPTIVE_SYNC_ENABLED);
+  g_assert_cmpint (g_slist_length (config1->outputs), ==, 1);
+
 
   g_assert_cmpint (g_slist_length (config2->outputs), ==, 2);
 }
@@ -46,22 +53,24 @@ test_phoc_config_output (void)
 static void
 test_phoc_config_modelines (void)
 {
-  GSList *modes;
+  PhocOutputConfig *oc;
+
   g_autoptr (PhocConfig) config = phoc_config_new_from_data (
     "[output:X11-1]\n"
     "modeline = 87.25  720 776 848 976  1440 1443 1453 1493 -hsync +vsync\n"
     "modeline = 87.25  720 776 848 976  1440 1443 1453 1493 -hsync +vsync\n"
     "scale = 3\n");
 
+  oc = config->outputs->data;
   g_assert_cmpint (g_slist_length (config->outputs), ==, 1);
-  g_assert_cmpint (((PhocOutputConfig*)config->outputs->data)->scale, ==, 3);
-  modes = ((PhocOutputConfig*)config->outputs->data)->modes;
-  g_assert_cmpint (g_slist_length (modes), ==, 2);
+  g_assert_cmpfloat (oc->scale, ==, 3.0);
+  g_assert_cmpint (oc->adaptive_sync, ==, PHOC_OUTPUT_ADAPTIVE_SYNC_NONE);
+  g_assert_cmpint (g_slist_length (oc->modes), ==, 2);
 }
 
 
 gint
-main (gint argc, gchar *argv[])
+main (gint argc, char *argv[])
 {
   g_test_init (&argc, &argv, NULL);
 
