@@ -133,7 +133,7 @@ shm_format (void *data, struct wl_shm *wl_shm, guint32 format)
 {
   PhocTestClientGlobals *globals = data;
 
-  globals->formats |= (1 << format);
+  g_ptr_array_add (globals->formats, GUINT_TO_POINTER (format));
 }
 
 
@@ -401,6 +401,7 @@ wl_client_run (GTask *task, gpointer source, gpointer data, GCancellable *cancel
   PhocTestClientGlobals globals = {
     .output_config = td->output_config,
     .display = wl_display_connect (NULL),
+    .formats = g_ptr_array_new (),
   };
 
   g_assert_nonnull (globals.display);
@@ -414,7 +415,7 @@ wl_client_run (GTask *task, gpointer source, gpointer data, GCancellable *cancel
   g_assert_nonnull (globals.xdg_shell);
   g_assert_nonnull (globals.gtk_shell1);
 
-  g_assert (globals.formats & (1 << WL_SHM_FORMAT_XRGB8888));
+  g_assert (g_ptr_array_find (globals.formats, GINT_TO_POINTER (WL_SHM_FORMAT_XRGB8888), NULL));
 
   if (td->func)
     success = (td->func)(&globals, td->data);
@@ -432,6 +433,7 @@ wl_client_run (GTask *task, gpointer source, gpointer data, GCancellable *cancel
   g_clear_pointer (&globals.shm, wl_shm_destroy);
   g_clear_pointer (&globals.compositor, wl_compositor_destroy);
   g_clear_pointer (&globals.output.output, wl_output_destroy);
+  g_clear_pointer (&globals.formats, g_ptr_array_unref);
 
   wl_registry_destroy (registry);
 
@@ -484,34 +486,7 @@ build_compositor_config (PhocTestClientIface *iface)
   if (G_APPROX_VALUE (output_config->scale, 0.0, FLT_EPSILON))
     output_config->scale = 1.0;
 
-  switch (output_config->transform) {
-  case WL_OUTPUT_TRANSFORM_NORMAL:
-    transform = "normal";
-    break;
-  case WL_OUTPUT_TRANSFORM_90:
-    transform = "90";
-    break;
-  case WL_OUTPUT_TRANSFORM_180:
-    transform = "180";
-    break;
-  case WL_OUTPUT_TRANSFORM_270:
-    transform = "270";
-    break;
-  case WL_OUTPUT_TRANSFORM_FLIPPED:
-    transform = "flipped";
-    break;
-  case WL_OUTPUT_TRANSFORM_FLIPPED_90:
-    transform = "flipped-90";
-    break;
-  case WL_OUTPUT_TRANSFORM_FLIPPED_180:
-    transform = "flipped-180";
-    break;
-  case WL_OUTPUT_TRANSFORM_FLIPPED_270:
-    transform = "flipped-270";
-    break;
-  default:
-    g_assert_not_reached ();
-  }
+  transform = phoc_utils_transform_to_str (output_config->transform);
 
   config_str = g_strdup_printf (
     "[core]\n"
@@ -781,7 +756,7 @@ phoc_test_buffer_equal (PhocTestBuffer *buf1, PhocTestBuffer *buf2)
  * Returns: %TRUE if buffers was saved successfully, otherwise %FALSE
  */
 gboolean
-phoc_test_buffer_save (PhocTestBuffer *buffer, const gchar *filename)
+phoc_test_buffer_save (PhocTestBuffer *buffer, const char *filename)
 {
   cairo_surface_t *surface;
   cairo_status_t status;
@@ -808,7 +783,7 @@ phoc_test_buffer_save (PhocTestBuffer *buffer, const gchar *filename)
 G_DEFINE_AUTOPTR_CLEANUP_FUNC (cairo_surface_t, cairo_surface_destroy)
 
 gboolean
-phoc_test_buffer_matches_screenshot (PhocTestBuffer *buffer, const gchar *filename)
+phoc_test_buffer_matches_screenshot (PhocTestBuffer *buffer, const char *filename)
 {
   const char *msg;
   g_autoptr (cairo_surface_t) surface = cairo_image_surface_create_from_png (filename);
